@@ -6,13 +6,14 @@ SHORT_DESCRIPTION = "Python Wrapper around the Huskoll API."
 setup(
     name="huskoll",
     packages=["huskoll"],
-    version="0.1",
+    version="0.1.1",
     license="MIT",
     description=SHORT_DESCRIPTION,
     long_description=README,
+    long_description_content_type="text/markdown",
     author="sotpotatis",
     url="https://github.com/sotpotatis/Huskoll-Python",
-    download_url="https://github.com/sotpotatis/Huskoll-Python/archive/v_01.tar.gz",
+    download_url="https://github.com/sotpotatis/Huskoll-Python/archive/v_011.tar.gz",
     keywords=["api", "huskoll"],
     install_requires=[
         "dateutil",
